package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;

public class KEKIdentifier extends ASN1Encodable {
   private ASN1OctetString keyIdentifier;
   private DERGeneralizedTime date;
   private OtherKeyAttribute other;

   public KEKIdentifier(byte[] keyIdentifier, DERGeneralizedTime date, OtherKeyAttribute other) {
      KEKIdentifier var10000 = this;
      KEKIdentifier var10001 = this;
      KEKIdentifier var10002 = this;
      super();
      DEROctetString var4;
      var4 = new DEROctetString.<init>(keyIdentifier);
      var10002.keyIdentifier = var4;
      var10001.date = date;
      var10000.other = other;
   }

   public KEKIdentifier(ASN1Sequence seq) {
      this.keyIdentifier = (ASN1OctetString)seq.getObjectAt(0);
      int var2;
      if ((var2 = seq.size()) != 1) {
         if (var2 != 2) {
            if (var2 != 3) {
               throw new IllegalArgumentException("Invalid KEKIdentifier");
            }

            this.date = (DERGeneralizedTime)seq.getObjectAt(1);
            this.other = OtherKeyAttribute.getInstance(seq.getObjectAt(2));
         } else if (seq.getObjectAt(1) instanceof DERGeneralizedTime) {
            this.date = (DERGeneralizedTime)seq.getObjectAt(1);
         } else {
            this.other = OtherKeyAttribute.getInstance(seq.getObjectAt(1));
         }
      }

   }

   public static KEKIdentifier getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static KEKIdentifier getInstance(Object obj) {
      if (obj != null && !(obj instanceof KEKIdentifier)) {
         if (obj instanceof ASN1Sequence) {
            return new KEKIdentifier((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid KEKIdentifier: " + obj.getClass().getName());
         }
      } else {
         return (KEKIdentifier)obj;
      }
   }

   public ASN1OctetString getKeyIdentifier() {
      return this.keyIdentifier;
   }

   public DERGeneralizedTime getDate() {
      return this.date;
   }

   public OtherKeyAttribute getOther() {
      return this.other;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.keyIdentifier);
      DERGeneralizedTime var2;
      if ((var2 = this.date) != null) {
         var1.add(var2);
      }

      OtherKeyAttribute var3;
      if ((var3 = this.other) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }
}
